@@ -122,7 +122,9 @@ MEMBER_ROWS = (
     'updated_at',
     'weight',
     'monitor_port',
-    'monitor_address')
+    'monitor_address',
+    'backup'
+)
 
 MEMBER_COLUMNS = (
     'id',
@@ -145,6 +147,7 @@ L7POLICY_ROWS = (
     'updated_at',
     'redirect_pool_id',
     'redirect_url',
+    'redirect_prefix',
     'action',
     'position',
     'id',
@@ -250,6 +253,7 @@ AMPHORA_ROWS = (
     'created_at',
     'updated_at',
     'image_id',
+    'compute_flavor',
 )
 
 AMPHORA_COLUMNS = (
